**1. Disclaimer**
*Vacation Extender* is a mathematical aid tool. We are **not responsible** for conflicts with your HR or local laws. Always validate official dates.

**2. Data Privacy**
Your data is processed in memory only and is **never stored**. Everything is deleted when you close the tab.